@@ -1005,10 +1005,12 @@ terminal_screen_system_font_changed_cb (GSettings      *settings,
                                         const char     *key,
                                         TerminalScreen *screen)
 {
+  TerminalScreenPrivate *priv = screen->priv;
+
   if (!gtk_widget_get_realized (GTK_WIDGET (screen)))
     return;
 
-  if (!g_settings_get_boolean (settings, TERMINAL_PROFILE_USE_SYSTEM_FONT_KEY))
+  if (!g_settings_get_boolean (priv->profile, TERMINAL_PROFILE_USE_SYSTEM_FONT_KEY))
     return;
 
   terminal_screen_set_font (screen);
@@ -1387,7 +1389,8 @@ terminal_screen_do_exec (TerminalScreen *screen,
 
   profile = priv->profile;
 
-  if (priv->initial_working_directory)
+  if (priv->initial_working_directory &&
+      !g_settings_get_boolean (profile, TERMINAL_PROFILE_USE_CUSTOM_COMMAND_KEY))
     working_dir = priv->initial_working_directory;
   else
     working_dir = g_get_home_dir ();
